module.exports = defineTest({
	description: 'Adds trailing semicolons for modules'
});
